@@ -5,7 +5,7 @@
  * This file defines Horde's core API interface. Other core Horde libraries
  * can interact with Kronolith through this API.
  *
- * Copyright 2010-2016 Horde LLC (http://www.horde.org/)
+ * Copyright 2010-2017 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.horde.org/licenses/gpl.
@@ -47,7 +47,7 @@ class Kronolith_Application extends Horde_Registry_Application
 
     /**
      */
-    public $version = 'H5 (4.2.19)';
+    public $version = 'H5 (4.2.22)';
 
     /**
      * Global variables defined:
@@ -162,7 +162,7 @@ class Kronolith_Application extends Horde_Registry_Application
         if (Kronolith::getDefaultCalendar(Horde_Perms::EDIT) &&
             ($perms->hasAppPermission('max_events') === true ||
              $perms->hasAppPermission('max_events') > Kronolith::countEvents())) {
-            $sidebar->addNewButton(_("_New Event"), Horde::url('new.php')->add('url', Horde::selfUrl(true, false, true)));
+            $sidebar->addNewButton(_("_New Event"), Horde::url('new.php')->add('url', Horde::signUrl(Horde::selfUrl(true, false, true))));
         }
 
         if (strlen($GLOBALS['session']->get('kronolith', 'display_cal'))) {
@@ -407,7 +407,8 @@ class Kronolith_Application extends Horde_Registry_Application
             $kronolith_shares = $GLOBALS['injector']->getInstance('Kronolith_Shares');
             $shares = $kronolith_shares->listShares(
                 $user,
-                array('attributes' => $user));
+                array('attributes' => $user)
+            );
             foreach ($shares as $share) {
                 $kronolith_shares->removeShare($share);
             }
