@@ -9,7 +9,7 @@
  * - user:     The user name for HTTP Basic Authentication.
  * - password: The password for HTTP Basic Authentication.
  *
- * Copyright 2004-2016 Horde LLC (http://www.horde.org/)
+ * Copyright 2004-2017 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.horde.org/licenses/gpl.
@@ -111,10 +111,17 @@ class Kronolith_Driver_Ical extends Kronolith_Driver
                                    array $options = array())
     {
         if ($this->isCalDAV()) {
-            return $this->_listCalDAVEvents(
-                $startDate, $endDate, $options['show_recurrence'],
-                $options['has_alarm'], $options['json'],
-                $options['cover_dates'], $options['hide_exceptions']);
+            try {
+                return $this->_listCalDAVEvents(
+                    $startDate, $endDate, $options['show_recurrence'],
+                    $options['has_alarm'], $options['json'],
+                    $options['cover_dates'], $options['hide_exceptions']);
+            } catch (Kronolith_Exception $e) {
+                // Fall back to regular ICS downloads. At least Nextcloud
+                // advertises calendars as CalDAV capable, but then denying
+                // CalDAV requests.
+                $this->_davSupport = false;
+            }
         }
         return $this->_listWebDAVEvents(
             $startDate, $endDate, $options['show_recurrence'],
